ColorUtils class

Constructors

ColorUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getHorizontalShadow(Color color) → HSLColor
Get the horizontal shadow HSLColor from the given color. The shadow color depends on the lightness of the given color.
getVerticalShadow(Color color) → HSLColor
Get the vertical shadow HSLColor from the given color. The shadow color depends on the lightness of the given color.